#!/usr/env python

import io
import os
import MAUS

def main():
    geometry_root_dir = os.getenv('ERIT_ROOT')

    if geometry_root_dir == '':
        err_msg = """
    To run the MAUS install of ERIT_FFAG you need to set the environment variable
        ERIT_ROOT
    to point at the root of your bzr branch.
    """
        raise EnvironmentError(err_msg)

    # This input generates empty spills, to be filled by the beam maker later on
    my_input = MAUS.InputPySpillGenerator()

    # Create an empty array of mappers, then populate it
    # with the functionality you want to use.
    my_map = MAUS.MapPyGroup()
    my_map.append(MAUS.MapPyBeamMaker()) # beam construction
    my_map.append(MAUS.MapCppSimulation())  #  geant4 simulation
    # can specify datacards here or by using appropriate command line calls
    datacards = io.StringIO(u"")
    # Then construct a MAUS output component - filename comes from datacards
    my_output = MAUS.OutputPyJSON()

    # The Go() drives all the components you pass in, then check the file
    # (default simulation.out) for output

    MAUS.Go(my_input, my_map, MAUS.ReducePyDoNothing(), my_output, datacards)
    
if __name__=="__main__":
    main()


